@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 
 """Init the Glances software."""
@@ -29,7 +19,7 @@ import sys
 # Global name
 # Version should start and end with a numerical char
 # See https://packaging.python.org/specifications/core-metadata/#version
-__version__ = '3.2.3'
+__version__ = '3.2.7'
 __author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
 __license__ = 'LGPLv3'
 
@@ -42,9 +32,11 @@ except ImportError:
 
 # Import Glances libs
 # Note: others Glances libs will be imported optionally
+from glances.compat import PY3
 from glances.logger import logger
 from glances.main import GlancesMain
 from glances.timer import Counter
+
 # Check locale
 try:
     locale.setlocale(locale.LC_ALL, '')
@@ -63,6 +55,10 @@ if psutil_version_info < psutil_min_version:
     print('psutil 5.3.0 or higher is needed. Glances cannot start.')
     sys.exit(1)
 
+# Trac malloc is only available on Python 3.4 or higher
+if PY3:
+    import tracemalloc
+
 
 def __signal_handler(signal, frame):
     """Callback for CTRL-C."""
@@ -78,7 +74,7 @@ def end():
         # ...after starting the server mode (issue #1175)
         pass
 
-    logger.info("Glances stopped (keypressed: CTRL-C)")
+    logger.info("Glances stopped (key pressed: CTRL-C)")
 
     # The end...
     sys.exit(0)
@@ -90,6 +86,9 @@ def start(config, args):
     # Load mode
     global mode
 
+    if args.trace_malloc or args.memory_leak:
+        tracemalloc.start()
+
     start_duration = Counter()
 
     if core.is_standalone():
@@ -110,6 +109,20 @@ def start(config, args):
 
     # Start the main loop
     logger.debug("Glances started in {} seconds".format(start_duration.get()))
+    if args.stop_after:
+        logger.info('Glances will be stopped in ~{} seconds'.format(args.stop_after * args.time * args.memory_leak * 2))
+
+    if args.memory_leak:
+        print(
+            'Memory leak detection, please wait ~{} seconds...'.format(
+                args.stop_after * args.time * args.memory_leak * 2
+            )
+        )
+        # First run without dump to fill the memory
+        mode.serve_n(args.stop_after)
+        # Then start the memory-leak loop
+        snapshot_begin = tracemalloc.take_snapshot()
+
     if args.stdout_issue or args.stdout_apidoc:
         # Serve once for issue/test mode
         mode.serve_issue()
@@ -117,6 +130,22 @@ def start(config, args):
         # Serve forever
         mode.serve_forever()
 
+    if args.memory_leak:
+        snapshot_end = tracemalloc.take_snapshot()
+        snapshot_diff = snapshot_end.compare_to(snapshot_begin, 'filename')
+        memory_leak = sum([s.size_diff for s in snapshot_diff])
+        print("Memory comsumption: {0:.1f}KB (see log for details)".format(memory_leak / 1000))
+        logger.info("Memory consumption (top 5):")
+        for stat in snapshot_diff[:5]:
+            logger.info(stat)
+    elif args.trace_malloc:
+        # See more options here: https://docs.python.org/3/library/tracemalloc.html
+        snapshot = tracemalloc.take_snapshot()
+        top_stats = snapshot.statistics("filename")
+        print("[ Trace malloc - Top 10 ]")
+        for stat in top_stats[:10]:
+            print(stat)
+
     # Shutdown
     mode.end()
 
@@ -132,18 +161,19 @@ def main():
 
     # Log Glances and psutil version
     logger.info('Start Glances {}'.format(__version__))
-    logger.info('{} {} and psutil {} detected'.format(
-        platform.python_implementation(),
-        platform.python_version(),
-        psutil_version))
+    logger.info(
+        '{} {} ({}) and psutil {} detected'.format(
+            platform.python_implementation(), platform.python_version(), sys.executable, psutil_version
+        )
+    )
 
     # Share global var
     global core
 
     # Create the Glances main instance
-    # Glances options from the command line are readed first (in __init__)
+    # Glances options from the command line are read first (in __init__)
     # then the options from the config file (in parse_args)
     core = GlancesMain()
 
     # Glances can be ran in standalone, client or server mode
-    start(config=core.get_config(), args= core.get_args())
+    start(config=core.get_config(), args=core.get_args())
