@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Manage the AMPs list."""
 
@@ -58,7 +48,9 @@ class AmpsList(object):
 
         # Display a warning (deprecated) message if the monitor section exist
         if "monitor" in self.config.sections():
-            logger.warning("A deprecated [monitor] section exists in the Glances configuration file. You should use the new Applications Monitoring Process module instead (http://glances.readthedocs.io/en/develop/aoa/amps.html).")
+            logger.warning(
+                "A deprecated [monitor] section exists in the Glances configuration file. You should use the new Applications Monitoring Process module instead (http://glances.readthedocs.io/en/develop/aoa/amps.html)."
+            )
 
         header = "glances_"
         # For each AMP scrip, call the load_config method
@@ -113,13 +105,19 @@ class AmpsList(object):
                 # Do not update if the enable tag is set
                 continue
 
+            if v.regex() is None:
+                # If there is no regex, execute anyway (see issue #1690)
+                v.set_count(0)
+                # Call the AMP update method
+                thread = threading.Thread(target=v.update_wrapper, args=[[]])
+                thread.start()
+                continue
+
             amps_list = self._build_amps_list(v, processlist)
 
             if len(amps_list) > 0:
                 # At least one process is matching the regex
-                logger.debug("AMPS: {} processes {} detected ({})".format(len(amps_list),
-                                                                          k,
-                                                                          amps_list))
+                logger.debug("AMPS: {} processes {} detected ({})".format(len(amps_list), k, amps_list))
                 # Call the AMP update method
                 thread = threading.Thread(target=v.update_wrapper, args=[amps_list])
                 thread.start()
@@ -127,7 +125,7 @@ class AmpsList(object):
                 # Set the process number to 0
                 v.set_count(0)
                 if v.count_min() is not None and v.count_min() > 0:
-                    # Only display the "No running process message" if countmin is defined
+                    # Only display the "No running process message" if count_min is defined
                     v.set_result("No running process")
 
         return self.__amps_dict
@@ -142,17 +140,20 @@ class AmpsList(object):
             # Search in both cmdline and name (for kernel thread, see #1261)
             for p in processlist:
                 add_it = False
-                if (re.search(amp_value.regex(), p['name']) is not None):
+                if re.search(amp_value.regex(), p['name']) is not None:
                     add_it = True
                 else:
+                    if p['cmdline'] is None:
+                        # See issue #1689 (thanks to @darylkell)
+                        continue
                     for c in p['cmdline']:
-                        if (re.search(amp_value.regex(), c) is not None):
+                        if re.search(amp_value.regex(), c) is not None:
                             add_it = True
                             break
                 if add_it:
-                    ret.append({'pid': p['pid'],
-                                'cpu_percent': p['cpu_percent'],
-                                'memory_percent': p['memory_percent']})
+                    ret.append(
+                        {'pid': p['pid'], 'cpu_percent': p['cpu_percent'], 'memory_percent': p['memory_percent']}
+                    )
 
         except (TypeError, KeyError) as e:
             logger.debug("Can not build AMPS list ({})".format(e))
