@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Manage sparklines for Glances output."""
 
@@ -43,7 +33,7 @@ except (UnicodeEncodeError, TypeError) as e:
 
 class Sparkline(object):
 
-    r"""Manage sparklines (see https://pypi.org/project/sparklines/)."""
+    """Manage sparklines (see https://pypi.org/project/sparklines/)."""
 
     def __init__(self, size, pre_char='[', post_char=']', empty_char=' ', with_text=True):
         # If the sparklines python module available ?
@@ -64,7 +54,7 @@ class Sparkline(object):
 
     @property
     def size(self, with_decoration=False):
-        # Return the sparkine size, with or without decoration
+        # Return the sparkline size, with or without decoration
         if with_decoration:
             return self.__size
         if self.__with_text:
