@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """CPU plugin."""
 
@@ -36,79 +26,113 @@ import psutil
 # rate: is it a rate ? If yes, // by time_since_update when displayed,
 # min_symbol: Auto unit should be used if value > than 1 'X' (K, M, G)...
 fields_description = {
-    'total': {'description': 'Sum of all CPU percentages (except idle).',
-              'unit': 'percent'},
-    'system': {'description': 'percent time spent in kernel space. System CPU time is the \
+    'total': {'description': 'Sum of all CPU percentages (except idle).', 'unit': 'percent'},
+    'system': {
+        'description': 'percent time spent in kernel space. System CPU time is the \
 time spent running code in the Operating System kernel.',
-               'unit': 'percent'},
-    'user': {'description': 'CPU percent time spent in user space. \
+        'unit': 'percent',
+    },
+    'user': {
+        'description': 'CPU percent time spent in user space. \
 User CPU time is the time spent on the processor running your program\'s code (or code in libraries).',
-             'unit': 'percent'},
-    'iowait': {'description': '*(Linux)*: percent time spent by the CPU waiting for I/O \
+        'unit': 'percent',
+    },
+    'iowait': {
+        'description': '*(Linux)*: percent time spent by the CPU waiting for I/O \
 operations to complete.',
-               'unit': 'percent'},
-    'idle': {'description': 'percent of CPU used by any program. Every program or task \
+        'unit': 'percent',
+    },
+    'idle': {
+        'description': 'percent of CPU used by any program. Every program or task \
 that runs on a computer system occupies a certain amount of processing \
 time on the CPU. If the CPU has completed all tasks it is idle.',
-             'unit': 'percent'},
-    'irq': {'description': '*(Linux and BSD)*: percent time spent servicing/handling \
+        'unit': 'percent',
+    },
+    'irq': {
+        'description': '*(Linux and BSD)*: percent time spent servicing/handling \
 hardware/software interrupts. Time servicing interrupts (hardware + \
 software).',
-            'unit': 'percent'},
-    'nice': {'description': '*(Unix)*: percent time occupied by user level processes with \
+        'unit': 'percent',
+    },
+    'nice': {
+        'description': '*(Unix)*: percent time occupied by user level processes with \
 a positive nice value. The time the CPU has spent running users\' \
 processes that have been *niced*.',
-             'unit': 'percent'},
-    'steal': {'description': '*(Linux)*: percentage of time a virtual CPU waits for a real \
+        'unit': 'percent',
+    },
+    'steal': {
+        'description': '*(Linux)*: percentage of time a virtual CPU waits for a real \
 CPU while the hypervisor is servicing another virtual processor.',
-              'unit': 'percent'},
-    'ctx_switches': {'description': 'number of context switches (voluntary + involuntary) per \
+        'unit': 'percent',
+    },
+    'ctx_switches': {
+        'description': 'number of context switches (voluntary + involuntary) per \
 second. A context switch is a procedure that a computer\'s CPU (central \
 processing unit) follows to change from one task (or process) to \
 another while ensuring that the tasks do not conflict.',
-                     'unit': 'number',
-                     'rate': True,
-                     'min_symbol': 'K',
-                     'short_name': 'ctx_sw'},
-    'interrupts': {'description': 'number of interrupts per second.',
-                   'unit': 'number',
-                   'rate': True,
-                   'min_symbol': 'K',
-                   'short_name': 'inter'},
-    'soft_interrupts': {'description': 'number of software interrupts per second. Always set to \
+        'unit': 'number',
+        'rate': True,
+        'min_symbol': 'K',
+        'short_name': 'ctx_sw',
+    },
+    'interrupts': {
+        'description': 'number of interrupts per second.',
+        'unit': 'number',
+        'rate': True,
+        'min_symbol': 'K',
+        'short_name': 'inter',
+    },
+    'soft_interrupts': {
+        'description': 'number of software interrupts per second. Always set to \
 0 on Windows and SunOS.',
-                        'unit': 'number',
-                        'rate': True,
-                        'min_symbol': 'K',
-                        'short_name': 'sw_int'},
-    'cpucore': {'description': 'Total number of CPU core.',
-                'unit': 'number'},
-    'time_since_update': {'description': 'Number of seconds since last update.',
-                          'unit': 'seconds'},
+        'unit': 'number',
+        'rate': True,
+        'min_symbol': 'K',
+        'short_name': 'sw_int',
+    },
+    'syscalls': {
+        'description': 'number of system calls per second. Always 0 on Linux OS.',
+        'unit': 'number',
+        'rate': True,
+        'min_symbol': 'K',
+        'short_name': 'sys_call',
+    },
+    'cpucore': {
+        'description': 'Total number of CPU core.',
+        'unit': 'number'
+    },
+    'time_since_update': {
+        'description': 'Number of seconds since last update.',
+        'unit': 'seconds'
+    },
 }
 
 # SNMP OID
 # percentage of user CPU time: .1.3.6.1.4.1.2021.11.9.0
 # percentages of system CPU time: .1.3.6.1.4.1.2021.11.10.0
 # percentages of idle CPU time: .1.3.6.1.4.1.2021.11.11.0
-snmp_oid = {'default': {'user': '1.3.6.1.4.1.2021.11.9.0',
-                        'system': '1.3.6.1.4.1.2021.11.10.0',
-                        'idle': '1.3.6.1.4.1.2021.11.11.0'},
-            'windows': {'percent': '1.3.6.1.2.1.25.3.3.1.2'},
-            'esxi': {'percent': '1.3.6.1.2.1.25.3.3.1.2'},
-            'netapp': {'system': '1.3.6.1.4.1.789.1.2.1.3.0',
-                       'idle': '1.3.6.1.4.1.789.1.2.1.5.0',
-                       'cpucore': '1.3.6.1.4.1.789.1.2.1.6.0'}}
+snmp_oid = {
+    'default': {
+        'user': '1.3.6.1.4.1.2021.11.9.0',
+        'system': '1.3.6.1.4.1.2021.11.10.0',
+        'idle': '1.3.6.1.4.1.2021.11.11.0',
+    },
+    'windows': {'percent': '1.3.6.1.2.1.25.3.3.1.2'},
+    'esxi': {'percent': '1.3.6.1.2.1.25.3.3.1.2'},
+    'netapp': {
+        'system': '1.3.6.1.4.1.789.1.2.1.3.0',
+        'idle': '1.3.6.1.4.1.789.1.2.1.5.0',
+        'cpucore': '1.3.6.1.4.1.789.1.2.1.6.0',
+    },
+}
 
 # Define the history items list
 # - 'name' define the stat identifier
 # - 'y_unit' define the Y label
-items_history_list = [{'name': 'user',
-                       'description': 'User CPU usage',
-                       'y_unit': '%'},
-                      {'name': 'system',
-                       'description': 'System CPU usage',
-                       'y_unit': '%'}]
+items_history_list = [
+    {'name': 'user', 'description': 'User CPU usage', 'y_unit': '%'},
+    {'name': 'system', 'description': 'System CPU usage', 'y_unit': '%'},
+]
 
 
 class Plugin(GlancesPlugin):
@@ -120,10 +144,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the CPU plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list,
-                                     fields_description=fields_description)
+        super(Plugin, self).__init__(
+            args=args, config=config, items_history_list=items_history_list, fields_description=fields_description
+        )
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -213,8 +236,7 @@ class Plugin(GlancesPlugin):
             # You can find the CPU utilization of windows system by querying the oid
             # Give also the number of core (number of element in the table)
             try:
-                cpu_stats = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
-                                                bulk=True)
+                cpu_stats = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name], bulk=True)
             except KeyError:
                 self.reset()
 
@@ -231,13 +253,11 @@ class Plugin(GlancesPlugin):
             stats['total'] = 100 - stats['idle']
 
         else:
-            # Default behavor
+            # Default behavior
             try:
-                stats = self.get_stats_snmp(
-                    snmp_oid=snmp_oid[self.short_system_name])
+                stats = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name])
             except KeyError:
-                stats = self.get_stats_snmp(
-                    snmp_oid=snmp_oid['default'])
+                stats = self.get_stats_snmp(snmp_oid=snmp_oid['default'])
 
             if stats['idle'] == '':
                 self.reset()
@@ -255,7 +275,7 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert and log
         for key in ['user', 'system', 'iowait', 'total']:
             if key in self.stats:
@@ -267,7 +287,9 @@ class Plugin(GlancesPlugin):
         # Alert only but depend on Core number
         for key in ['ctx_switches']:
             if key in self.stats:
-                self.views[key]['decoration'] = self.get_alert(self.stats[key], maximum=100 * self.stats['cpucore'], header=key)
+                self.views[key]['decoration'] = self.get_alert(
+                    self.stats[key], maximum=100 * self.stats['cpucore'], header=key
+                )
         # Optional
         for key in ['nice', 'irq', 'idle', 'steal', 'ctx_switches', 'interrupts', 'soft_interrupts', 'syscalls']:
             if key in self.stats:
@@ -283,7 +305,7 @@ class Plugin(GlancesPlugin):
             return ret
 
         # If user stat is not here, display only idle / total CPU usage (for
-        # exemple on Windows OS)
+        # example on Windows OS)
         idle_tag = 'user' not in self.stats
 
         # First line
@@ -300,16 +322,13 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(msg))
         # Total CPU usage
         msg = '{:5.1f}%'.format(self.stats['total'])
-        ret.append(self.curse_add_line(
-            msg, self.get_views(key='total', option='decoration')))
+        ret.append(self.curse_add_line(msg, self.get_views(key='total', option='decoration')))
         # Idle CPU
         if 'idle' in self.stats and not idle_tag:
-            msg = '  {:8}'.format('idle:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle',
-                                                                        option='optional')))
-            msg = '{:5.1f}%'.format(self.stats['idle'])
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle',
-                                                                        option='optional')))
+            msg = '  {:8}'.format('idle')
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
+            msg = '{:4.1f}%'.format(self.stats['idle'])
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
         # ctx_switches
         ret.extend(self.curse_add_stat('ctx_switches', width=15, header='  '))
 
@@ -322,7 +341,7 @@ class Plugin(GlancesPlugin):
         elif 'idle' in self.stats:
             ret.extend(self.curse_add_stat('idle', width=15))
         # IRQ CPU
-        ret.extend(self.curse_add_stat('irq', width=15, header='  '))
+        ret.extend(self.curse_add_stat('irq', width=14, header='  '))
         # interrupts
         ret.extend(self.curse_add_stat('interrupts', width=15, header='  '))
 
@@ -335,17 +354,17 @@ class Plugin(GlancesPlugin):
         else:
             ret.extend(self.curse_add_stat('core', width=15))
         # Nice CPU
-        ret.extend(self.curse_add_stat('nice', width=15, header='  '))
+        ret.extend(self.curse_add_stat('nice', width=14, header='  '))
         # soft_interrupts
         ret.extend(self.curse_add_stat('soft_interrupts', width=15, header='  '))
 
         # Fourth line
-        # iowat + steal + syscalls
+        # iowait + steal + syscalls
         ret.append(self.curse_new_line())
         # IOWait CPU
         ret.extend(self.curse_add_stat('iowait', width=15))
         # Steal CPU usage
-        ret.extend(self.curse_add_stat('steal', width=15, header='  '))
+        ret.extend(self.curse_add_stat('steal', width=14, header='  '))
         # syscalls: number of system calls since boot. Always set to 0 on Linux. (do not display)
         if not LINUX:
             ret.extend(self.curse_add_stat('syscalls', width=15, header='  '))
