@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Docker plugin."""
 
@@ -23,7 +13,6 @@ import os
 import threading
 import time
 from copy import deepcopy
-from dateutil import parser
 
 from glances.compat import iterkeys, itervalues, nativestr, pretty_date
 from glances.logger import logger
@@ -35,10 +24,11 @@ from glances.timer import getTimeSinceLastUpdate
 # https://github.com/docker/docker-py
 try:
     import docker
+    from dateutil import parser, tz
 except Exception as e:
     import_error_tag = True
     # Display debug message if import KeyError
-    logger.warning("Error loading Docker Python Lib. Docker plugin is disabled ({})".format(e))
+    logger.warning("Error loading Docker deps Lib. Docker plugin is disabled ({})".format(e))
 else:
     import_error_tag = False
 
@@ -236,12 +226,8 @@ class Plugin(GlancesPlugin):
             # Get stats for all containers
             stats['containers'] = []
             for container in containers:
-                # Only show specific containers
-                if not self.is_show(nativestr(container.name)):
-                    continue
-
-                # Do not take hidden container into account
-                if self.is_hide(nativestr(container.name)):
+                # Shall we display the stats ?
+                if not self.is_display(nativestr(container.name)):
                     continue
 
                 # Init the stats for the current container
@@ -293,7 +279,8 @@ class Plugin(GlancesPlugin):
                     container_stats['network_tx'] = container_stats['network'].get('tx', None)
                     # Uptime
                     container_stats['Uptime'] = pretty_date(
-                        parser.parse(container.attrs['State']['StartedAt']).replace(tzinfo=None)
+                        # parser.parse(container.attrs['State']['StartedAt']).replace(tzinfo=None)
+                        parser.parse(container.attrs['State']['StartedAt']).astimezone(tz.tzlocal()).replace(tzinfo=None)
                     )
                 else:
                     container_stats['cpu'] = {}
