@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Folder plugin."""
 from __future__ import unicode_literals
@@ -33,9 +23,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     stats_init_value=[])
+        super(Plugin, self).__init__(args=args, config=config, stats_init_value=[])
         self.args = args
         self.config = config
 
@@ -52,7 +40,7 @@ class Plugin(GlancesPlugin):
     @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
-        """Update the foldered list."""
+        """Update the folders list."""
         # Init new stats
         stats = self.get_init_value()
 
@@ -62,7 +50,7 @@ class Plugin(GlancesPlugin):
             if self.glances_folders is None:
                 return self.stats
 
-            # Update the foldered list (result of command)
+            # Update the folders list (result of command)
             self.glances_folders.update()
 
             # Put it on the stats var
@@ -82,14 +70,11 @@ class Plugin(GlancesPlugin):
         else:
             ret = 'OK'
 
-            if stat['critical'] is not None and \
-               stat['size'] > int(stat['critical']) * 1000000:
+            if stat['critical'] is not None and stat['size'] > int(stat['critical']) * 1000000:
                 ret = 'CRITICAL'
-            elif stat['warning'] is not None and \
-                    stat['size'] > int(stat['warning']) * 1000000:
+            elif stat['warning'] is not None and stat['size'] > int(stat['warning']) * 1000000:
                 ret = 'WARNING'
-            elif stat['careful'] is not None and \
-                    stat['size'] > int(stat['careful']) * 1000000:
+            elif stat['careful'] is not None and stat['size'] > int(stat['careful']) * 1000000:
                 ret = 'CAREFUL'
 
         # Get stat name
@@ -99,10 +84,7 @@ class Plugin(GlancesPlugin):
         self.manage_threshold(stat_name, ret)
 
         # Manage action
-        self.manage_action(stat_name,
-                           ret.lower(),
-                           header,
-                           stat[self.get_key()])
+        self.manage_action(stat_name, ret.lower(), header, stat[self.get_key()])
 
         return ret
 
@@ -112,15 +94,14 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disabled():
             return ret
 
         # Max size for the interface name
         name_max_width = max_width - 7
 
         # Header
-        msg = '{:{width}}'.format('FOLDERS',
-                                  width=name_max_width)
+        msg = '{:{width}}'.format('FOLDERS', width=name_max_width)
         ret.append(self.curse_add_line(msg, "TITLE"))
 
         # Data
@@ -128,17 +109,15 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_new_line())
             if len(i['path']) > name_max_width:
                 # Cut path if it is too long
-                path = '_' + i['path'][-name_max_width + 1:]
+                path = '_' + i['path'][-name_max_width + 1 :]
             else:
                 path = i['path']
-            msg = '{:{width}}'.format(nativestr(path),
-                                      width=name_max_width)
+            msg = '{:{width}}'.format(nativestr(path), width=name_max_width)
             ret.append(self.curse_add_line(msg))
             try:
                 msg = '{:>9}'.format(self.auto_unit(i['size']))
             except (TypeError, ValueError):
                 msg = '{:>9}'.format(i['size'])
-            ret.append(self.curse_add_line(msg, self.get_alert(i,
-                                                               header='folder_' + i['indice'])))
+            ret.append(self.curse_add_line(msg, self.get_alert(i, header='folder_' + i['indice'])))
 
         return ret
