@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """IP plugin."""
 
@@ -24,7 +14,7 @@ from json import loads
 
 from glances.compat import iterkeys, urlopen, queue
 from glances.logger import logger
-from glances.timer import Timer
+from glances.timer import Timer, getTimeSinceLastUpdate
 from glances.plugins.glances_plugin import GlancesPlugin
 
 # Import plugin specific dependency
@@ -56,6 +46,9 @@ class Plugin(GlancesPlugin):
     stats is a dict
     """
 
+    _default_public_refresh_interval = 300
+    _default_public_ip_disabled = ["False"]
+
     def __init__(self, args=None, config=None):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args, config=config)
@@ -63,9 +56,14 @@ class Plugin(GlancesPlugin):
         # We want to display the stat in the curse interface
         self.display_curse = True
 
-        # Get the public IP address once (not for each refresh)
-        if not import_error_tag:
-            self.public_address = PublicIpAddress().get()
+        # For public IP address
+        self.public_address = ""
+        self.public_address_refresh_interval = self.get_conf_value(
+            "public_refresh_interval", default=self._default_public_refresh_interval
+        )
+
+        public_ip_disabled = self.get_conf_value("public_ip_disabled", default=self._default_public_ip_disabled)
+        self.public_ip_disabled = True if public_ip_disabled == ["True"] else False
 
     @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
@@ -83,15 +81,26 @@ class Plugin(GlancesPlugin):
                 default_gw = netifaces.gateways()['default'][netifaces.AF_INET]
             except (KeyError, AttributeError) as e:
                 logger.debug("Cannot grab the default gateway ({})".format(e))
+                return {}
+
+            try:
+                address = netifaces.ifaddresses(default_gw[1])[netifaces.AF_INET][0]['addr']
+                mask = netifaces.ifaddresses(default_gw[1])[netifaces.AF_INET][0]['netmask']
+
+                time_since_update = getTimeSinceLastUpdate('public-ip')
+                if not self.public_ip_disabled and (
+                    self.stats.get('address') != address or time_since_update > self.public_address_refresh_interval
+                ):
+                    self.public_address = PublicIpAddress().get()
+            except (KeyError, AttributeError) as e:
+                logger.debug("Cannot grab IP information: {}".format(e))
             else:
-                try:
-                    stats['address'] = netifaces.ifaddresses(default_gw[1])[netifaces.AF_INET][0]['addr']
-                    stats['mask'] = netifaces.ifaddresses(default_gw[1])[netifaces.AF_INET][0]['netmask']
-                    stats['mask_cidr'] = self.ip_to_cidr(stats['mask'])
-                    stats['gateway'] = netifaces.gateways()['default'][netifaces.AF_INET][0]
-                    stats['public_address'] = self.public_address
-                except (KeyError, AttributeError) as e:
-                    logger.debug("Cannot grab IP information: {}".format(e))
+                stats['address'] = address
+                stats['mask'] = mask
+                stats['mask_cidr'] = self.ip_to_cidr(stats['mask'])
+                stats['gateway'] = default_gw[0]
+                stats['public_address'] = self.public_address
+
         elif self.input_method == 'snmp':
             # Not implemented yet
             pass
@@ -138,7 +147,7 @@ class Plugin(GlancesPlugin):
             # Add KeyError exception (see https://github.com/nicolargo/glances/issues/1469)
             pass
         else:
-            if self.stats['public_address'] is not None:
+            if self.stats['public_address']:
                 msg = ' Pub '
                 ret.append(self.curse_add_line(msg, 'TITLE'))
                 ret.append(self.curse_add_line(msg_pub))
