@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Load plugin."""
 
@@ -29,38 +19,47 @@ from glances.logger import logger
 
 # Fields description
 fields_description = {
-    'min1': {'description': 'Average sum of the number of processes \
+    'min1': {
+        'description': 'Average sum of the number of processes \
 waiting in the run-queue plus the number currently executing \
 over 1 minute.',
-             'unit': 'number'},
-    'min5': {'description': 'Average sum of the number of processes \
+        'unit': 'float',
+    },
+    'min5': {
+        'description': 'Average sum of the number of processes \
 waiting in the run-queue plus the number currently executing \
 over 5 minutes.',
-             'unit': 'number'},
-    'min15': {'description': 'Average sum of the number of processes \
+        'unit': 'float',
+    },
+    'min15': {
+        'description': 'Average sum of the number of processes \
 waiting in the run-queue plus the number currently executing \
 over 15 minutes.',
-              'unit': 'number'},
-    'cpucore': {'description': 'Total number of CPU core.',
-                'unit': 'number'},
+        'unit': 'float',
+    },
+    'cpucore': {
+        'description': 'Total number of CPU core.',
+        'unit': 'number'
+    },
 }
 
 # SNMP OID
 # 1 minute Load: .1.3.6.1.4.1.2021.10.1.3.1
 # 5 minute Load: .1.3.6.1.4.1.2021.10.1.3.2
 # 15 minute Load: .1.3.6.1.4.1.2021.10.1.3.3
-snmp_oid = {'min1': '1.3.6.1.4.1.2021.10.1.3.1',
-            'min5': '1.3.6.1.4.1.2021.10.1.3.2',
-            'min15': '1.3.6.1.4.1.2021.10.1.3.3'}
+snmp_oid = {
+    'min1': '1.3.6.1.4.1.2021.10.1.3.1',
+    'min5': '1.3.6.1.4.1.2021.10.1.3.2',
+    'min15': '1.3.6.1.4.1.2021.10.1.3.3',
+}
 
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
-items_history_list = [{'name': 'min1',
-                       'description': '1 minute load'},
-                      {'name': 'min5',
-                       'description': '5 minutes load'},
-                      {'name': 'min15',
-                       'description': '15 minutes load'}]
+items_history_list = [
+    {'name': 'min1', 'description': '1 minute load'},
+    {'name': 'min5', 'description': '5 minutes load'},
+    {'name': 'min15', 'description': '15 minutes load'},
+]
 
 
 class Plugin(GlancesPlugin):
@@ -71,10 +70,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list,
-                                     fields_description=fields_description)
+        super(Plugin, self).__init__(
+            args=args, config=config, items_history_list=items_history_list, fields_description=fields_description
+        )
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -90,7 +88,7 @@ class Plugin(GlancesPlugin):
         """Get load average. On both Linux and Windows thanks to PsUtil"""
         try:
             return psutil.getloadavg()
-        except AttributeError:
+        except (AttributeError, OSError):
             pass
         try:
             return os.getloadavg()
@@ -112,10 +110,7 @@ class Plugin(GlancesPlugin):
             if load is None:
                 stats = self.get_init_value()
             else:
-                stats = {'min1': load[0],
-                         'min5': load[1],
-                         'min15': load[2],
-                         'cpucore': self.nb_log_core}
+                stats = {'min1': load[0], 'min5': load[1], 'min15': load[2], 'cpucore': self.nb_log_core}
 
         elif self.input_method == 'snmp':
             # Update stats using SNMP
@@ -145,11 +140,11 @@ class Plugin(GlancesPlugin):
         # Add specifics informations
         try:
             # Alert and log
-            self.views['min15']['decoration'] = self.get_alert_log(self.stats['min15'],
-                                                                   maximum=100 * self.stats['cpucore'])
+            self.views['min15']['decoration'] = self.get_alert_log(
+                self.stats['min15'], maximum=100 * self.stats['cpucore']
+            )
             # Alert only
-            self.views['min5']['decoration'] = self.get_alert(self.stats['min5'],
-                                                              maximum=100 * self.stats['cpucore'])
+            self.views['min5']['decoration'] = self.get_alert(self.stats['min5'], maximum=100 * self.stats['cpucore'])
         except KeyError:
             # try/except mandatory for Windows compatibility (no load stats)
             pass
@@ -160,34 +155,32 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist, not empty (issue #871) and plugin not disabled
-        if not self.stats or (self.stats == {}) or self.is_disable():
+        if not self.stats or (self.stats == {}) or self.is_disabled():
             return ret
 
         # Build the string message
         # Header
-        msg = '{:6}'.format('LOAD%' if (args.disable_irix and self.nb_log_core != 0) else 'LOAD')
+        msg = '{:4}'.format('LOAD')
         ret.append(self.curse_add_line(msg, "TITLE"))
+        msg = ' {:1}'.format(self.trend_msg(self.get_trend('min1')))
+        ret.append(self.curse_add_line(msg))
         # Core number
         if 'cpucore' in self.stats and self.stats['cpucore'] > 0:
-            msg = '{:3}-core'.format(int(self.stats['cpucore']))
+            msg = '{:3}core'.format(int(self.stats['cpucore']))
             ret.append(self.curse_add_line(msg))
         # Loop over 1min, 5min and 15min load
         for load_time in ['1', '5', '15']:
             ret.append(self.curse_new_line())
-            msg = '{:8}'.format('{} min:'.format(load_time))
+            msg = '{:7}'.format('{} min'.format(load_time))
             ret.append(self.curse_add_line(msg))
             if args.disable_irix and self.nb_log_core != 0:
                 # Enable Irix mode for load (see issue #1554)
                 load_stat = self.stats['min{}'.format(load_time)] / self.nb_log_core * 100
+                msg = '{:>5.1f}%'.format(load_stat)
             else:
+                # Default mode for load
                 load_stat = self.stats['min{}'.format(load_time)]
-            msg = '{:>6.2f}'.format(load_stat)
-            if load_time == '1':
-                ret.append(self.curse_add_line(msg))
-            else:
-                # Alert is only for 5 and 15 min
-                ret.append(self.curse_add_line(
-                    msg, self.get_views(key='min{}'.format(load_time),
-                                        option='decoration')))
+                msg = '{:>6.2f}'.format(load_stat)
+            ret.append(self.curse_add_line(msg, self.get_views(key='min{}'.format(load_time), option='decoration')))
 
         return ret
