@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Virtual memory plugin."""
 
@@ -25,6 +15,63 @@ from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
 
+# Fields description
+fields_description = {
+    'total': {'description': 'Total physical memory available.', 'unit': 'bytes', 'min_symbol': 'K'},
+    'available': {
+        'description': 'The actual amount of available memory that can be given instantly \
+to processes that request more memory in bytes; this is calculated by summing \
+different memory values depending on the platform (e.g. free + buffers + cached on Linux) \
+and it is supposed to be used to monitor actual memory usage in a cross platform fashion.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'percent': {
+        'description': 'The percentage usage calculated as (total - available) / total * 100.',
+        'unit': 'percent',
+    },
+    'used': {
+        'description': 'Memory used, calculated differently depending on the platform and \
+designed for informational purposes only.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'free': {
+        'description': 'Memory not being used at all (zeroed) that is readily available; \
+note that this doesn\'t reflect the actual memory available (use \'available\' instead).',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'active': {
+        'description': '*(UNIX)*: memory currently in use or very recently used, and so it is in RAM.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'inactive': {
+        'description': '*(UNIX)*: memory that is marked as not used.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+        'short_name': 'inacti',
+    },
+    'buffers': {
+        'description': '*(Linux, BSD)*: cache for things like file system metadata.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+        'short_name': 'buffer',
+    },
+    'cached': {'description': '*(Linux, BSD)*: cache for various things.', 'unit': 'bytes', 'min_symbol': 'K'},
+    'wired': {
+        'description': '*(BSD, macOS)*: memory that is marked to always stay in RAM. It is never moved to disk.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'shared': {
+        'description': '*(BSD)*: memory that may be simultaneously accessed by multiple processes.',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+}
+
 # SNMP OID
 # Total RAM in machine: .1.3.6.1.4.1.2021.4.5.0
 # Total RAM used: .1.3.6.1.4.1.2021.4.6.0
@@ -33,25 +80,31 @@ import psutil
 # Total RAM Buffered: .1.3.6.1.4.1.2021.4.14.0
 # Total Cached Memory: .1.3.6.1.4.1.2021.4.15.0
 # Note: For Windows, stats are in the FS table
-snmp_oid = {'default': {'total': '1.3.6.1.4.1.2021.4.5.0',
-                        'free': '1.3.6.1.4.1.2021.4.11.0',
-                        'shared': '1.3.6.1.4.1.2021.4.13.0',
-                        'buffers': '1.3.6.1.4.1.2021.4.14.0',
-                        'cached': '1.3.6.1.4.1.2021.4.15.0'},
-            'windows': {'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
-                        'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
-                        'size': '1.3.6.1.2.1.25.2.3.1.5',
-                        'used': '1.3.6.1.2.1.25.2.3.1.6'},
-            'esxi': {'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
-                     'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
-                     'size': '1.3.6.1.2.1.25.2.3.1.5',
-                     'used': '1.3.6.1.2.1.25.2.3.1.6'}}
+snmp_oid = {
+    'default': {
+        'total': '1.3.6.1.4.1.2021.4.5.0',
+        'free': '1.3.6.1.4.1.2021.4.11.0',
+        'shared': '1.3.6.1.4.1.2021.4.13.0',
+        'buffers': '1.3.6.1.4.1.2021.4.14.0',
+        'cached': '1.3.6.1.4.1.2021.4.15.0',
+    },
+    'windows': {
+        'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
+        'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
+        'size': '1.3.6.1.2.1.25.2.3.1.5',
+        'used': '1.3.6.1.2.1.25.2.3.1.6',
+    },
+    'esxi': {
+        'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
+        'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
+        'size': '1.3.6.1.2.1.25.2.3.1.5',
+        'used': '1.3.6.1.2.1.25.2.3.1.6',
+    },
+}
 
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
-items_history_list = [{'name': 'percent',
-                       'description': 'RAM memory usage',
-                       'y_unit': '%'}]
+items_history_list = [{'name': 'percent', 'description': 'RAM memory usage', 'y_unit': '%'}]
 
 
 class Plugin(GlancesPlugin):
@@ -62,9 +115,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list)
+        super(Plugin, self).__init__(
+            args=args, config=config, items_history_list=items_history_list, fields_description=fields_description
+        )
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -90,7 +143,7 @@ class Plugin(GlancesPlugin):
             # percent: the percentage usage calculated as (total - available) / total * 100.
             # used: memory used, calculated differently depending on the platform and designed for informational
             # purposes only.
-            # free: memory not being used at all (zeroed) that is readily available; note that this doesn’t
+            # free: memory not being used at all (zeroed) that is readily available; note that this doesn't
             # reflect the actual memory available (use ‘available’ instead).
             # Platform-specific fields:
             # active: (UNIX): memory currently in use or very recently used, and so it is in RAM.
@@ -100,9 +153,19 @@ class Plugin(GlancesPlugin):
             # wired: (BSD, macOS): memory that is marked to always stay in RAM. It is never moved to disk.
             # shared: (BSD): memory that may be simultaneously accessed by multiple processes.
             self.reset()
-            for mem in ['total', 'available', 'percent', 'used', 'free',
-                        'active', 'inactive', 'buffers', 'cached',
-                        'wired', 'shared']:
+            for mem in [
+                'total',
+                'available',
+                'percent',
+                'used',
+                'free',
+                'active',
+                'inactive',
+                'buffers',
+                'cached',
+                'wired',
+                'shared',
+            ]:
                 if hasattr(vm_stats, mem):
                     stats[mem] = getattr(vm_stats, mem)
 
@@ -120,8 +183,7 @@ class Plugin(GlancesPlugin):
             if self.short_system_name in ('windows', 'esxi'):
                 # Mem stats for Windows|Vmware Esxi are stored in the FS table
                 try:
-                    fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
-                                                  bulk=True)
+                    fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name], bulk=True)
                 except KeyError:
                     self.reset()
                 else:
@@ -135,7 +197,7 @@ class Plugin(GlancesPlugin):
                             stats['free'] = stats['total'] - stats['used']
                             break
             else:
-                # Default behavor for others OS
+                # Default behavior for others OS
                 stats = self.get_stats_snmp(snmp_oid=snmp_oid['default'])
 
                 if stats['total'] == '':
@@ -165,7 +227,7 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert and log
         self.views['percent']['decoration'] = self.get_alert_log(self.stats['used'], maximum=self.stats['total'])
         # Optional
@@ -179,64 +241,43 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and plugin not disabled
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disabled():
             return ret
 
-        # Build the string message
-        # Header
+        # First line
+        # total% + active
         msg = '{}'.format('MEM')
         ret.append(self.curse_add_line(msg, "TITLE"))
         msg = ' {:2}'.format(self.trend_msg(self.get_trend('percent')))
         ret.append(self.curse_add_line(msg))
         # Percent memory usage
         msg = '{:>7.1%}'.format(self.stats['percent'] / 100)
-        ret.append(self.curse_add_line(
-            msg, self.get_views(key='percent', option='decoration')))
+        ret.append(self.curse_add_line(msg, self.get_views(key='percent', option='decoration')))
         # Active memory usage
-        if 'active' in self.stats:
-            msg = '  {:9}'.format('active:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='active', option='optional')))
-            msg = '{:>7}'.format(self.auto_unit(self.stats['active']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='active', option='optional')))
-        # New line
+        ret.extend(self.curse_add_stat('active', width=16, header='  '))
+
+        # Second line
+        # total + inactive
         ret.append(self.curse_new_line())
         # Total memory usage
-        msg = '{:6}'.format('total:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>7}'.format(self.auto_unit(self.stats['total']))
-        ret.append(self.curse_add_line(msg))
+        ret.extend(self.curse_add_stat('total', width=15))
         # Inactive memory usage
-        if 'inactive' in self.stats:
-            msg = '  {:9}'.format('inactive:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='inactive', option='optional')))
-            msg = '{:>7}'.format(self.auto_unit(self.stats['inactive']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='inactive', option='optional')))
-        # New line
+        ret.extend(self.curse_add_stat('inactive', width=16, header='  '))
+
+        # Third line
+        # used + buffers
         ret.append(self.curse_new_line())
         # Used memory usage
-        msg = '{:6}'.format('used:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>7}'.format(self.auto_unit(self.stats['used']))
-        ret.append(self.curse_add_line(
-            msg, self.get_views(key='used', option='decoration')))
+        ret.extend(self.curse_add_stat('used', width=15))
         # Buffers memory usage
-        if 'buffers' in self.stats:
-            msg = '  {:9}'.format('buffers:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='buffers', option='optional')))
-            msg = '{:>7}'.format(self.auto_unit(self.stats['buffers']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='buffers', option='optional')))
-        # New line
+        ret.extend(self.curse_add_stat('buffers', width=16, header='  '))
+
+        # Fourth line
+        # free + cached
         ret.append(self.curse_new_line())
         # Free memory usage
-        msg = '{:6}'.format('free:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>7}'.format(self.auto_unit(self.stats['free']))
-        ret.append(self.curse_add_line(msg))
+        ret.extend(self.curse_add_stat('free', width=15))
         # Cached memory usage
-        if 'cached' in self.stats:
-            msg = '  {:9}'.format('cached:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='cached', option='optional')))
-            msg = '{:>7}'.format(self.auto_unit(self.stats['cached']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='cached', option='optional')))
+        ret.extend(self.curse_add_stat('cached', width=16, header='  '))
 
         return ret
