@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 I am your father...
@@ -28,7 +18,7 @@ import json
 import copy
 from operator import itemgetter
 
-from glances.compat import iterkeys, itervalues, listkeys, map, mean, nativestr, u
+from glances.compat import iterkeys, itervalues, listkeys, map, mean, nativestr
 from glances.actions import GlancesActions
 from glances.history import GlancesHistory
 from glances.logger import logger
@@ -38,7 +28,9 @@ from glances.timer import Counter, Timer
 from glances.outputs.glances_unicode import unicode_message
 
 
-fields_unit_short = {'percent': '%'}
+fields_unit_short = {
+    'percent': '%'
+}
 
 fields_unit_type = {
     'percent': 'float',
@@ -52,7 +44,7 @@ fields_unit_type = {
     'second': 'int',
     'seconds': 'int',
     'byte': 'int',
-    'bytes': 'int',
+    'bytes': 'int'
 }
 
 
@@ -425,6 +417,10 @@ class GlancesPlugin(object):
         """Return the stats object in JSON format."""
         return self._json_dumps(self.stats)
 
+    def get_json(self):
+        """Return the stats object in JSON format."""
+        return self.get_stats()
+
     def get_stats_item(self, item):
         """Return the stats object for a specific item in JSON format.
 
@@ -879,10 +875,7 @@ class GlancesPlugin(object):
         show=sda.*
         """
         # @TODO: possible optimisation: create a re.compile list
-        if self.get_conf_value('show', header=header) == []:
-            return True
-        else:
-            return any(j for j in [re.match(i, value) for i in self.get_conf_value('show', header=header)])
+        return any(j for j in [re.match(i, value) for i in self.get_conf_value('show', header=header)])
 
     def is_hide(self, value, header=""):
         """Return True if the value is in the hide configuration list.
@@ -895,6 +888,14 @@ class GlancesPlugin(object):
         # @TODO: possible optimisation: create a re.compile list
         return any(j for j in [re.match(i, value) for i in self.get_conf_value('hide', header=header)])
 
+    def is_display(self, value, header=""):
+        """Return True if the value should be displayed in the UI
+        """
+        if self.get_conf_value('show', header=header) != []:
+            return self.is_show(value, header=header)
+        else:
+            return not self.is_hide(value, header=header)
+
     def has_alias(self, header):
         """Return the alias name for the relative header it it exists otherwise None."""
         try:
@@ -969,7 +970,7 @@ class GlancesPlugin(object):
         """Go to a new line."""
         return self.curse_add_line('\n')
 
-    def curse_add_stat(self, key, width=None, header='', separator='', trailer=''):
+    def curse_add_stat(self, key, width=None, header='', display_key=True, separator='', trailer=''):
         """Return a list of dict messages with the 'key: value' result
 
           <=== width ===>
@@ -977,8 +978,8 @@ class GlancesPlugin(object):
         | |       | |    |_ trailer
         | |       | |_ self.stats[key]
         | |       |_ separator
-        | |_ key
-        |_ trailer
+        | |_ 'short_name' description or key or nothing if display_key is True
+        |_ header
 
         Instead of:
             msg = '  {:8}'.format('idle:')
@@ -994,7 +995,9 @@ class GlancesPlugin(object):
             return []
 
         # Check if a shortname is defined
-        if key in self.fields_description and 'short_name' in self.fields_description[key]:
+        if not display_key:
+            key_name = ''
+        elif key in self.fields_description and 'short_name' in self.fields_description[key]:
             key_name = self.fields_description[key]['short_name']
         else:
             key_name = key
@@ -1099,7 +1102,7 @@ class GlancesPlugin(object):
         """
         symbols = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
         if min_symbol in symbols:
-            symbols = symbols[symbols.index(min_symbol) :]
+            symbols = symbols[symbols.index(min_symbol):]
         prefix = {
             'Y': 1208925819614629174706176,
             'Z': 1180591620717411303424,
@@ -1177,7 +1180,7 @@ class GlancesPlugin(object):
                 "%s %s %s return %s in %s seconds"
                 % (
                     args[0].__class__.__name__,
-                    args[0].__class__.__module__[len('glances_') :],
+                    args[0].__class__.__module__[len('glances_'):],
                     fct.__name__,
                     ret,
                     duration,
