@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2020 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# You should have received a copy of the GNU Lesser General Public License
 
 """Quicklook plugin."""
 
@@ -30,18 +20,12 @@ import psutil
 
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
-items_history_list = [{'name': 'cpu',
-                       'description': 'CPU percent usage',
-                       'y_unit': '%'},
-                      {'name': 'percpu',
-                       'description': 'PERCPU percent usage',
-                       'y_unit': '%'},
-                      {'name': 'mem',
-                       'description': 'MEM percent usage',
-                       'y_unit': '%'},
-                      {'name': 'swap',
-                       'description': 'SWAP percent usage',
-                       'y_unit': '%'}]
+items_history_list = [
+    {'name': 'cpu', 'description': 'CPU percent usage', 'y_unit': '%'},
+    {'name': 'percpu', 'description': 'PERCPU percent usage', 'y_unit': '%'},
+    {'name': 'mem', 'description': 'MEM percent usage', 'y_unit': '%'},
+    {'name': 'swap', 'description': 'SWAP percent usage', 'y_unit': '%'},
+]
 
 
 class Plugin(GlancesPlugin):
@@ -52,9 +36,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the quicklook plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list)
+        super(Plugin, self).__init__(args=args, config=config, items_history_list=items_history_list)
         # We want to display the stat in the curse interface
         self.display_curse = True
 
@@ -82,7 +64,9 @@ class Plugin(GlancesPlugin):
             # Get additional information
             cpu_info = cpu_percent.get_info()
             stats['cpu_name'] = cpu_info['cpu_name']
-            stats['cpu_hz_current'] = self._mhz_to_hz(cpu_info['cpu_hz_current']) if cpu_info['cpu_hz_current'] is not None else None
+            stats['cpu_hz_current'] = (
+                self._mhz_to_hz(cpu_info['cpu_hz_current']) if cpu_info['cpu_hz_current'] is not None else None
+            )
             stats['cpu_hz'] = self._mhz_to_hz(cpu_info['cpu_hz']) if cpu_info['cpu_hz'] is not None else None
 
         elif self.input_method == 'snmp':
@@ -99,7 +83,7 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert only
         for key in ['cpu', 'mem', 'swap']:
             if key in self.stats:
@@ -111,26 +95,25 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist...
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disabled():
             return ret
 
-        # Define the data: Bar (default behavor) or Sparkline
+        # Define the data: Bar (default behavior) or Sparkline
         sparkline_tag = False
         if self.args.sparkline and self.history_enable() and not self.args.client:
             data = Sparkline(max_width)
             sparkline_tag = data.available
         if not sparkline_tag:
             # Fallback to bar if Sparkline module is not installed
-            data = Bar(max_width,
-                       percentage_char=self.get_conf_value('percentage_char',
-                                                           default=['|'])[0])
+            data = Bar(max_width, percentage_char=self.get_conf_value('percentage_char', default=['|'])[0])
 
         # Build the string message
         if 'cpu_name' in self.stats and 'cpu_hz_current' in self.stats and 'cpu_hz' in self.stats:
             msg_name = self.stats['cpu_name']
             if self.stats['cpu_hz_current'] and self.stats['cpu_hz']:
-                msg_freq = ' - {:.2f}/{:.2f}GHz'.format(self._hz_to_ghz(self.stats['cpu_hz_current']),
-                                                        self._hz_to_ghz(self.stats['cpu_hz']))
+                msg_freq = ' - {:.2f}/{:.2f}GHz'.format(
+                    self._hz_to_ghz(self.stats['cpu_hz_current']), self._hz_to_ghz(self.stats['cpu_hz'])
+                )
             else:
                 msg_freq = ''
             if len(msg_name + msg_freq) - 6 <= max_width:
@@ -176,16 +159,14 @@ class Plugin(GlancesPlugin):
         return ret
 
     def _msg_create_line(self, msg, data, key):
-        """Create a new line to the Quickview."""
-        ret = []
-
-        ret.append(self.curse_add_line(msg))
-        ret.append(self.curse_add_line(data.pre_char, decoration='BOLD'))
-        ret.append(self.curse_add_line(data.get(), self.get_views(key=key, option='decoration')))
-        ret.append(self.curse_add_line(data.post_char, decoration='BOLD'))
-        ret.append(self.curse_add_line('  '))
-
-        return ret
+        """Create a new line to the Quick view."""
+        return [
+            self.curse_add_line(msg),
+            self.curse_add_line(data.pre_char, decoration='BOLD'),
+            self.curse_add_line(data.get(), self.get_views(key=key, option='decoration')),
+            self.curse_add_line(data.post_char, decoration='BOLD'),
+            self.curse_add_line('  '),
+        ]
 
     def _hz_to_ghz(self, hz):
         """Convert Hz to Ghz."""
@@ -193,4 +174,4 @@ class Plugin(GlancesPlugin):
 
     def _mhz_to_hz(self, hz):
         """Convert Mhz to Hz."""
-        return hz * 1000000.0
\ No newline at end of file
+        return hz * 1000000.0
