@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """The stats manager."""
 
@@ -109,7 +99,7 @@ class GlancesStats(object):
         # generate self._plugins_list["xxx"] = ...
         name = plugin_script[len(self.header) : -3].lower()
 
-        # Loaf the plugin class
+        # Load the plugin class
         try:
             # Import the plugin
             plugin = __import__(plugin_script[:-3])
@@ -120,13 +110,18 @@ class GlancesStats(object):
             # on the console but do not crash
             logger.critical("Error while initializing the {} plugin ({})".format(name, e))
             logger.error(traceback.format_exc())
-            # Disable the plugin
+            # An error occure, disable the plugin
             if args is not None:
                 setattr(args, 'disable_' + name, False)
         else:
-            # Set the disable_<name> to False by default
+            # Manage the default status of the plugin (enable or disable)
             if args is not None:
-                setattr(args, 'disable_' + name, getattr(args, 'disable_' + name, False))
+                # If the all key is set in the disable_plugin option then look in the enable_plugin option
+                if getattr(args, 'disable_all', False):
+                    logger.info('%s => %s', name, getattr(args, 'enable_' + name, False))
+                    setattr(args, 'disable_' + name, not getattr(args, 'enable_' + name, False))
+                else:
+                    setattr(args, 'disable_' + name, getattr(args, 'disable_' + name, False))
 
     def load_plugins(self, args=None):
         """Load all plugins in the 'plugins' folder."""
